==> haskell-binary-tagged-0.1.4.2-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-binary-tagged.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: binary-tagged
version: 0.1.4.2
id: binary-tagged-0.1.4.2-Leis0yRcGVA7DDqR92RpGa
key: binary-tagged-0.1.4.2-Leis0yRcGVA7DDqR92RpGa
license: BSD3
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/binary-tagged#readme
synopsis: Tagged binary serialisation.
description:
    Check <https://github.com/phadej/binary-tagged#readme README on Github>
category: Web
author: Oleg Grenrus <oleg.grenrus@iki.fi>
exposed: True
exposed-modules:
    Data.Binary.Tagged
abi: b6d3655d9cbfd8f0e5fcebaeb0274613
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/binary-tagged-0.1.4.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/binary-tagged-0.1.4.2
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/binary-tagged-0.1.4.2
hs-libraries: HSbinary-tagged-0.1.4.2-Leis0yRcGVA7DDqR92RpGa
depends:
    SHA-1.6.4.2-GSP9nhHyWNEAImBrL9QfXp
    aeson-1.0.2.1-580HLk2Nlp5BZ0wDg2BMVx array-0.5.1.1 base-4.9.0.0
    base16-bytestring-0.1.1.6-5dPoF8dzhwzBaEB2MvnmIS binary-0.8.3.0
    bytestring-0.10.8.1 containers-0.5.7.1
    generics-sop-0.2.4.0-8q0y0oRZNln24Ov1OYtww6
    hashable-1.2.5.0-22n1YftRkmj9O0NzIR6ge1
    scientific-0.3.4.10-HyHkymmV2uwD8dEKuPMVuU
    semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    unordered-containers-0.2.7.2-2cqAiy5FQsv48ljFn9vXL1
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-binary-tagged/html/binary-tagged.haddock
haddock-html: /usr/share/doc/haskell-binary-tagged/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-binary-tagged-0.1.4.2-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-binary-tagged.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: binary-tagged
version: 0.1.4.2
id: binary-tagged-0.1.4.2-2tEtHwsRX03eOC1pNk8Kd
key: binary-tagged-0.1.4.2-2tEtHwsRX03eOC1pNk8Kd
license: BSD3
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/binary-tagged#readme
synopsis: Tagged binary serialisation.
description:
    Check <https://github.com/phadej/binary-tagged#readme README on Github>
category: Web
author: Oleg Grenrus <oleg.grenrus@iki.fi>
exposed: True
exposed-modules:
    Data.Binary.Tagged
abi: 91dbbb995a07a5e53ebb1f5627f05975
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/binary-tagged-0.1.4.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/binary-tagged-0.1.4.2
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/binary-tagged-0.1.4.2
hs-libraries: HSbinary-tagged-0.1.4.2-2tEtHwsRX03eOC1pNk8Kd
depends:
    SHA-1.6.4.2-GSP9nhHyWNEAImBrL9QfXp
    aeson-1.0.2.1-12Tr6G2d7dgKxXx9Jv4gDD array-0.5.1.1 base-4.9.0.0
    base16-bytestring-0.1.1.6-5dPoF8dzhwzBaEB2MvnmIS binary-0.8.3.0
    bytestring-0.10.8.1 containers-0.5.7.1
    generics-sop-0.2.4.0-8q0y0oRZNln24Ov1OYtww6
    hashable-1.2.6.0-En2FSYN34Tp8YO8pqagtg1
    scientific-0.3.4.11-ICV8fOXZrxLGwVNBrNLr5f
    semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    unordered-containers-0.2.8.0-HozSxlbOa6oDZVsS46CFCU
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
haddock-interfaces: /usr/share/doc/haskell-binary-tagged/html/binary-tagged.haddock
haddock-html: /usr/share/doc/haskell-binary-tagged/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
